#! /bin/sh
#
# MySQL dump using MySQL root user - call as Linux root user!
# Part of mysql-addons package. Original from Alex Hornyak (THX!).
#
# Usage: mysql_dump.sh [backup_dir [backup_owner]]

compress="-c"                           # Compressed backup needed.
datetime=`date +%Y%m%d%H%M%S`           # Time string used in filenames.

# Need to be root. 
if [ ! $UID -eq 0 ]; then echo "Run as root, please." >&2; exit $EXIT_ERR; fi

# Getting parameters.
# Optional backup directory pathname defaults to ./timestamp.
bkuppath=${1:-`pwd`/$datetime}; shift
# Optional Linux user (backups owner) defaults to 'backup'.
dumpuser=${1:-"backup"}; shift
# Wired Linux owners group.
dumpdirgroup="disk"
# MySQL command line call as MySQL root user.
mysql_dsm="/usr/bin/mysql --defaults-file=/etc/mysql/root.cnf"
# Database dump script call.
mysqldump_dsm="/usr/local/sbin/mysql_dumpdb"

echo "$datetime $0 started."
# List of existing databases.
dblist=`$mysql_dsm --batch --execute='show databases;' | sed "s/^Database$//"`
if [ -n "$dblist" ]; then
    # Creating backup's directory is necessary.
    if [ ! -d "$bkuppath" ]; then 
        mkdir -m 2750 "$bkuppath"; chown $dumpuser:$dumpdirgroup "$bkuppath"
    else 
        # Doing some cleanup.
        rm "$bkuppath/*.sql" "$bkuppath/*.sql.gz"
    fi
    # Enumerating databases and doing dump via script call.
    for dbname in $dblist
    do
        filename="$bkuppath/`hostname`.$datetime.$dbname.sql"
        $mysqldump_dsm $compress $dbname "$filename" $dumpuser
    done
fi
echo `date +%Y%m%d%H%M%S`" $0 finished."
